<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 5/29/2012	ELL
// Modified: 12/2/2016	ELL
// Consolidated all class tables into site_classes table indexed by style_sheet field.
// Consolidated all CSS tables into site_css table indexed by style_sheet field.
// 
// 
// 
	
	include ("check_session.php");
	
	$class = $_POST['class'];
	$style_sheet = $_POST['style_sheet'];
	
	$replace = array(".", "#", " ", ",", ">", "&gt;", "+", "~");
	$search = array("PERIOD", "POUND", "SPACE", "COMMA", "GREATERTHAN", "GREATERTHAN", "PLUS", "TILDA");
	$class = str_replace($search, $replace, $class);
	
	$query = "SELECT `description` FROM `" . BWB_TABLE_PREFIX . "site_classes` WHERE `style_sheet` = '" . $style_sheet . "' AND `class`='" . $class . "'";
	$result = $bwb_dbh->query($query);
	
	if ($result->rowCount() < 1)
	{
		echo "-no data-";
		exit;
	}

	$row = $result->fetch(PDO::FETCH_ASSOC);
	echo $row['description'];

?>